This challenge can be skipped. It's for if you want users to run a Docker container and have an CLI experience with your app. You're building a cli app that takes turns asking the user information and waiting for the user to type a response into the terminal, and at the end of a series of questions, it reports back to the user or creates files on the system.

For our CLI App, we will use NodeJS's inquirer package. Python can make CLI apps too InquirerPy.

---

.dockerignore:
```
.DS_Store
node_modules
package-lock.json
__pycache__
*.pyc
.env
```

Dockerfile:
```
# Use the specific NodeJS base image (bundled in Debian)
FROM node:18

# Set the working directory in the container.
# All below commands will work from working directory.
WORKDIR /app

# Copy the package.json file to the container
COPY package.json .

# Install the NodeJS packages
RUN npm install

# Copy your application files (if any)
COPY . .

# Specify the command to run your application (optional, depends on your use case)
CMD ["node", "app.js"]
```

package.json:
```
{
  "dependencies": {
    "inquirer": "8.0.0"
  }
}
```

app.js:
```
const inquirer = require('inquirer');

inquirer
  .prompt([
    {
      type: 'input',
      name: 'firstName',
      message: 'What is your first name?'
    },
    {
      type: 'input', 
      name: 'lastName',
      message: 'What is your last name?'
    }
  ])
  .then(answers => {
    console.log(`Have a great day, ${answers.firstName} ${answers.lastName}!`);
  });
```

---

Let's build the image:
```
docker build -t inq-app .
```

Then we run it on port 3002 or your choice:
```
docker run -it inq-app
```

The command line would ask you to type your first and last name:
```
% docker run -it inq-app
? What is your first name? Weng
? What is your last name? Fung
Have a great day, Weng Fung!
```

Cleanup:
You can close off a container by the container id like so:
```
docker kill 377f9be6ece4
```


Distribution:
You are NOT uploading then making it available online at a port or URL because this is a terminal experience. 

Some industries still use CLI apps, especially when the information needs to be secured or there is resistance on upgrading legacy code, or the user is usually an engineer or developer who doesn't care about GUI. An example app is asking the user to input financial information and then it generates a financial statement in HTML or CSV. 

Likely you would create a repo where other developers can download your tool, then build the image, and run the container off of the image. Or you would host the image online.

Cleanup?
Let's not clean up. We will distribute this image online in the next challenge.

